FromNetReturn

Trait FromNetReturn 

pub unsafe trait FromNetReturn: 'static { }
Safety

This trait is implemented for Rust types which can be returned from .net delegates. This is a superset of types which implement FromNet, and allows returning eg. the unit () type, whose .net equivalent void cannot be used as a normal type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FromNetReturn for Result<(), NetException>

Source

impl FromNetReturn for ()

Source

impl<T: FromNet> FromNetReturn for Result<T, NetException>

Implementors