pub unsafe trait FromNetReturn: 'static { }Expand description
Safety
This trait is implemented for Rust types which can be returned from
.net delegates. This is a superset of types which implement FromNet,
and allows returning eg. the unit () type, whose .net equivalent
void cannot be used as a normal type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.